@@ -13,7 +13,7 @@
 function fd = fdread(filename)
 
 [s,w] = unix(['xdview -rasters ' filename ' 2>/dev/null']);
-if(strcmp(w,''))
+if(s~=0)
   filename = cat(2,filename,'.gz');
   [s,w] = unix(['xdview -rasters ' filename ' 2>/dev/null']);
 end
