@@ -8,7 +8,7 @@
 function [x,y,e,s,n] = xdview_curve(filename)
 
 [s,w] = unix(['xdview -curve -text ' filename]);
-if(strcmp(w,''))
+if(s~=0)
   filename = cat(2,filename,'.gz');
   [s,w] = unix(['xdview -curve -text ' filename]);
 end
