@@ -11,9 +11,10 @@ function x = xdview_isih(filename,mask)
 
 fd = fdread(filename);
 
-% Remove empty trials from fd.rasters
-idx=find(fd.rasters(:,2)==-1);
-fd.rasters=fdrasters(idx,:);
+% who put this here, and why?
+%% Remove empty trials from fd.rasters
+%idx=find(fd.rasters(:,2)==-1);
+%fd.rasters=fd.rasters(idx,:);
 
 idx = find(fd.rasters(:,3)==mask);
 foo = fd.rasters(idx,:);
