@@ -22,15 +22,16 @@
 extern "C" {
 #endif
 
-extern WidgetClass xfwfCircularPercentageWidgetClass;
+	extern WidgetClass xfwfCircularPercentageWidgetClass;
 
-typedef struct _XfwfCircularPercentageClassRec *XfwfCircularPercentageWidgetClass;
-typedef struct _XfwfCircularPercentageRec      *XfwfCircularPercentageWidget;
+	typedef struct _XfwfCircularPercentageClassRec
+	    *XfwfCircularPercentageWidgetClass;
+	typedef struct _XfwfCircularPercentageRec
+	    *XfwfCircularPercentageWidget;
 
-extern void XfwfCircularPercentageSetPercentage(Widget,int);
+	extern void XfwfCircularPercentageSetPercentage(Widget, int);
 
 #if defined(__cplusplus) || defined(c_plusplus)
-}  /* Close scope of 'extern "C"' declaration which encloses file. */
+}				/* Close scope of 'extern "C"' declaration which encloses file. */
 #endif
-
 #endif
