@@ -6,7 +6,7 @@
 */
 
 /******************************************************************
-**  RCSID: $Id: atgraph.h,v 2.45 1999/02/02 19:43:05 bjarthur Exp $
+**  RCSID: $Id: atgraph.h,v 2.46 2002/07/15 04:30:00 cmalek Exp $
 ** Program: dowl
 **  Module: atgraph
 **  Author: mazer
@@ -23,30 +23,31 @@
 #define _atgraph_h_
 
 typedef struct {
-  Widget plotter;
-  Widget xaxis;
-  Widget yaxis;
-  Widget bars;
+	Widget plotter;
+	Widget xaxis;
+	Widget yaxis;
+	Widget bars;
 
-  float *bins;
-  float *binvals;
-  int nbins;
-  float binwidth;
+	float *bins;
+	float *binvals;
+	int nbins;
+	float binwidth;
 
-  int xlog;
-  int ylog;
+	int xlog;
+	int ylog;
 } ATH;
 
 #define ath_linear	0
 #define ath_log		1
 
-extern	void atgraph_quick(char*, char*, char*, int, char **, int*,
-      float**, float**, float**, int);
+extern void atgraph_quick(char *, char *, char *, int, char **, int *,
+			  float **, float **, float **, int);
 
-extern 	ATH  *athisto_new(Widget, char*, char*, int, char*, int, int, float);
-extern  void  athisto_decay(ATH *h, float kappa);
-extern  int	  athisto_add(ATH*, float, int, float);
-extern  void  athisto_clear(ATH*);
-extern  void  athisto_update(ATH*);
+extern ATH *athisto_new(Widget, char *, char *, int, char *, int, int,
+			float);
+extern void athisto_decay(ATH * h, float kappa);
+extern int athisto_add(ATH *, float, int, float);
+extern void athisto_clear(ATH *);
+extern void athisto_update(ATH *);
 
-#endif /* _atgraph_h_ */
+#endif				/* _atgraph_h_ */
