@@ -6,7 +6,7 @@
 */
 
 /******************************************************************
-**  RCSID: $Id: getfile.h,v 2.43 1996/11/07 18:40:54 bjarthur Exp $
+**  RCSID: $Id: getfile.h,v 2.44 2002/07/15 04:30:08 cmalek Exp $
 ** Program: dowl
 **  Module: getfile.h
 **  Author: mazer
@@ -25,14 +25,14 @@
 #define GF_ALLFILES	NULL
 
 struct noblock_data {
-  Widget        pshell;
-  void          (*cbfn)();
-  caddr_t       cbdata;
-  int           once;
+	Widget pshell;
+	void (*cbfn) ();
+	caddr_t cbdata;
+	int once;
 };
 
-extern char *fileBoxMatch(char*, char*, char*, char*, int);
-extern char *fileBox(char*, char*, char*);
+extern char *fileBoxMatch(char *, char *, char *, char *, int);
+extern char *fileBox(char *, char *, char *);
 
-extern void  fileBoxMatch_noblock(char*, char*, char*, char*, int, void(*)(),
-      caddr_t, int);
+extern void fileBoxMatch_noblock(char *, char *, char *, char *, int,
+				 void (*)(), caddr_t, int);
