@@ -10,26 +10,22 @@
 	assert(((to)=(type*)malloc((n)*sizeof(type)))!=NULL); \
 	memcpy((to),(from),(n)*sizeof(type)); }
 
-extern int	debugflag;
-extern char	*progname;
-extern int	single_step_mode;
-extern int	cur_ntrials;
-extern int	cur_trialnum;
-extern int	cur_nreps;
-extern int	cur_repnum;
-extern int	cur_depvar;
+extern int debugflag;
+extern char *progname;
+extern int single_step_mode;
+extern int cur_ntrials;
+extern int cur_trialnum;
+extern int cur_nreps;
+extern int cur_repnum;
+extern int cur_depvar;
 
-extern char *shortname(char*);
+extern char *shortname(char *);
 
-extern int floatcompare(const void*, const void*);
-extern int intcompare(const void*, const void*);
+extern int floatcompare(const void *, const void *);
+extern int intcompare(const void *, const void *);
 
 #define SPONT (-6666)
 
-#ifndef AUTOLOG
-# define AUTOLOG "AutoLogFile"
-#endif
-
 #ifndef DRUGLOG
 # define DRUGLOG "DrugsLog"
 #endif
@@ -38,11 +34,11 @@ extern int intcompare(const void*, const void*);
 # define PASSLOG "PassLog"
 #endif
 
-extern char *next_alphanum_counter(char*, int);
+extern char *next_alphanum_counter(char *, int);
 
-extern void help(char*, char*);
+extern void help(char *, char *);
 
-extern char *strsave(char*);
+extern char *strsave(char *);
 
 extern void xd_setFc(int, int, int);
 extern int single_step(int);
@@ -54,7 +50,7 @@ double getRadWithArgs(double, double);
 #ifdef mc700
 
 /* these are part of libc on suns, but not mentioned in include/string.h */
-extern int 	strcasecmp(char*, char*);/* this is part of libc on suns */
-extern int 	strncasecmp(char*, char*, int);	/* this is part of libc on suns */
+extern int strcasecmp(char *, char *);	/* this is part of libc on suns */
+extern int strncasecmp(char *, char *, int);	/* this is part of libc on suns */
 
 #endif
