@@ -6,7 +6,7 @@
  */
 
 /******************************************************************
-**  RCSID: $Id: unittrace.c,v 2.65 2001/04/02 03:02:30 cmalek Exp $
+**  RCSID: $Id: unittrace.c,v 2.66 2002/07/15 04:30:24 cmalek Exp $
 ** Program: dowl
 **  Module: unittrace.c
 **  Author: mazer
@@ -141,17 +141,19 @@ static void ResetAction(Widget w, XEvent * event, String * params,
 	if (gsr_window_flag) {
 		if (G_detect_curr == 0) {
 			xword *ibuf;
-			int count, i, j; 
+			int count, i, j;
 			int nchans = is_getDAnchans();
 			float mean;
 
 			if (is_inited) {
 				if (!spiker_getTTLbuffer(&count, &ibuf)) {
-					alert("ResetAction: no ttl buffer found");
+					alert
+					    ("ResetAction: no ttl buffer found");
 					return;
 				}
 
-				for (j = 0, i = 0, mean = 0.0; j < count; j++, i += nchans)
+				for (j = 0, i = 0, mean = 0.0; j < count;
+				     j++, i += nchans)
 					mean += ibuf[i];
 				mean /= count;
 				G_detect_y[0] = mean;
@@ -193,11 +195,12 @@ static void ResetAllAction(Widget w, XEvent * event, String * params,
 				return;
 			}
 
-			for (j = 0, i = 0, mean = 0.0; j < count; j++, i += nchans)
+			for (j = 0, i = 0, mean = 0.0; j < count;
+			     j++, i += nchans)
 				mean += ibuf[i];
 			mean /= count;
 			G_detect_y[0] = mean;
-		} else 
+		} else
 			G_detect_y[0] = 0;
 
 		for (i = 1; i < 4; i++) {
@@ -233,7 +236,8 @@ static void AdjustAction(Widget w, XEvent * event, String * params,
 		jump_size = GI("detect.jump");
 
 		if (event->type == KeyPress) {
-			if (last_timestamp && (event->xkey.time - last_timestamp) < 200)
+			if (last_timestamp
+			    && (event->xkey.time - last_timestamp) < 200)
 				key_accel++;
 			else
 				key_accel = 1;
@@ -243,13 +247,15 @@ static void AdjustAction(Widget w, XEvent * event, String * params,
 		}
 
 		if (!strcasecmp(params[0], "up")) {
-			i = G_detect_y[G_detect_curr] + (jump_size * key_accel);
+			i = G_detect_y[G_detect_curr] +
+			    (jump_size * key_accel);
 			if (i > RANGE) {
 				i = RANGE;
 			}
 			G_detect_y[G_detect_curr] = i;
 		} else if (!strcasecmp(params[0], "down")) {
-			i = G_detect_y[G_detect_curr] - (jump_size * key_accel);
+			i = G_detect_y[G_detect_curr] -
+			    (jump_size * key_accel);
 			if (i < -RANGE) {
 				i = -RANGE;
 			}
@@ -264,8 +270,7 @@ static void AdjustAction(Widget w, XEvent * event, String * params,
 
 static void install_discrim_actions(Widget w)
 {
-	static XtActionsRec actions[] =
-	{
+	static XtActionsRec actions[] = {
 		{"discrim-setcurr", SetCurrAction},
 		{"discrim-togglecolor", ToggleColorAction},
 		{"discrim-toggleonoff", ToggleOnOffAction},
@@ -303,7 +308,8 @@ static void install_discrim_actions(Widget w)
    <Key>u:              discrim-set(upper)\n";
  */
 
-	XtAppAddActions(XtWidgetToApplicationContext(w), actions, XtNumber(actions));
+	XtAppAddActions(XtWidgetToApplicationContext(w), actions,
+			XtNumber(actions));
 	XtOverrideTranslations(w, XtParseTranslationTable(bindings));
 }
 
@@ -325,13 +331,16 @@ static void setmask(TRACER * t, int i)
 		t->mask = i;
 		switch (t->mask) {
 		case TTL_CODE:
-			XtVaSetValues(t->mask_button, XtNlabel, "TTL", NULL);
+			XtVaSetValues(t->mask_button, XtNlabel, "TTL",
+				      NULL);
 			break;
 		case OUTLIER_CODE:
-			XtVaSetValues(t->mask_button, XtNlabel, "OUT", NULL);
+			XtVaSetValues(t->mask_button, XtNlabel, "OUT",
+				      NULL);
 			break;
 		case MU_CODE:
-			XtVaSetValues(t->mask_button, XtNlabel, "MU", NULL);
+			XtVaSetValues(t->mask_button, XtNlabel, "MU",
+				      NULL);
 			break;
 		default:
 			sprintf(buf, "#%02d", t->mask);
@@ -450,7 +459,8 @@ static void SettingsCB(Widget w, XtPointer t_blah, XtPointer call_data)
 {
 	TRACER *t = (TRACER *) t_blah;
 
-	notify("Mask=%d, pre=%dms, post=%dms", t->mask, GI("mspre"), GI("mspost"));
+	notify("Mask=%d, pre=%dms, post=%dms", t->mask, GI("mspre"),
+	       GI("mspost"));
 }
 
 TRACER *tracer_new(Widget parent, int anatrace, int width, int height,
@@ -496,46 +506,52 @@ TRACER *tracer_new(Widget parent, int anatrace, int width, int height,
 
 	x = NULL;
 	if (popit)
-		x = button_new(t->form, "Close", "Close", CloseitCB, t, NULL, NULL);
+		x = button_new(t->form, "Close", "Close", CloseitCB, t,
+			       NULL, NULL);
 
 	t->active =
-	    x = toggle_new(t->form, "On", "On", x, NULL, NULL, NULL, NULL, True);
+	    x =
+	    toggle_new(t->form, "On", "On", x, NULL, NULL, NULL, NULL,
+		       True);
 	x = button_new(t->form, "Clear", "Clear", ClearCB, t, x, NULL);
 
 	t->mask_button = t->ssbutts[0] =
 	    x = button_new(t->form, "mask", "mask", MUMaskCB, t, x, NULL);
 	XtVaSetValues(t->mask_button, XtNresizable, True, NULL);
 	setmask(t, -1);
-	x = t->ssbutts[1] = button_new(t->form, "++", "++", IncMaskCB, t, x, NULL);
-	x = t->ssbutts[2] = button_new(t->form, "--", "--", DecMaskCB, t, x, NULL);
-	x = t->ssbutts[3] = button_new(t->form, "->TTL", "->TTL", TTLMaskCB, t, x, NULL);
-	x = t->ssbutts[4] = button_new(t->form, "->OUT", "->OUT", OUTMaskCB, t, x, NULL);
-	x = t->ssbutts[5] = button_new(t->form, "->?", "->?", SettingsCB, t, x, NULL);
-	x = t->ssbutts[6] = button_new(t->form, "Clone", "Clone", CloneCB, t, x, NULL);
+	x = t->ssbutts[1] =
+	    button_new(t->form, "++", "++", IncMaskCB, t, x, NULL);
+	x = t->ssbutts[2] =
+	    button_new(t->form, "--", "--", DecMaskCB, t, x, NULL);
+	x = t->ssbutts[3] =
+	    button_new(t->form, "->TTL", "->TTL", TTLMaskCB, t, x, NULL);
+	x = t->ssbutts[4] =
+	    button_new(t->form, "->OUT", "->OUT", OUTMaskCB, t, x, NULL);
+	x = t->ssbutts[5] =
+	    button_new(t->form, "->?", "->?", SettingsCB, t, x, NULL);
+	x = t->ssbutts[6] =
+	    button_new(t->form, "Clone", "Clone", CloneCB, t, x, NULL);
 
 	x = t->active;
 
-	t->paned = XtVaCreateManagedWidget("paned", panedWidgetClass, t->form,
-				      XtNwidth, width, XtNheight, height,
-					XtNorientation, XtorientVertical,
-					   XtNfromVert, x, NULL);
+	t->paned =
+	    XtVaCreateManagedWidget("paned", panedWidgetClass, t->form,
+				    XtNwidth, width, XtNheight, height,
+				    XtNorientation, XtorientVertical,
+				    XtNfromVert, x, NULL);
 
 	hform = form_new(t->paned, "histograms", -1);
-	t->psth = athisto_new(hform, NULL, NULL, ath_linear, NULL, ath_linear,
-			      100, 1.0);
-	XtVaSetValues(t->psth->plotter,
-		      XtNfromHoriz, NULL,
-		      XtNwidth, width / 2,
-		      XtNheight, height / splitby,
-		      NULL);
-	t->isih = athisto_new(hform, NULL, NULL, ath_linear, NULL, ath_linear,
-			      100, 0.20);
-	XtVaSetValues(t->isih->plotter,
-		      XtNfromHoriz, t->psth->plotter,
-		      XtNwidth, width / 2,
-		      XtNheight, height / splitby,
-		      XtNhorizDistance, 0,
-		      NULL);
+	t->psth =
+	    athisto_new(hform, NULL, NULL, ath_linear, NULL, ath_linear,
+			100, 1.0);
+	XtVaSetValues(t->psth->plotter, XtNfromHoriz, NULL, XtNwidth,
+		      width / 2, XtNheight, height / splitby, NULL);
+	t->isih =
+	    athisto_new(hform, NULL, NULL, ath_linear, NULL, ath_linear,
+			100, 0.20);
+	XtVaSetValues(t->isih->plotter, XtNfromHoriz, t->psth->plotter,
+		      XtNwidth, width / 2, XtNheight, height / splitby,
+		      XtNhorizDistance, 0, NULL);
 
 	t->raster = dynraster_new(t->paned, width, height / splitby, 20);
 
@@ -544,10 +560,11 @@ TRACER *tracer_new(Widget parent, int anatrace, int width, int height,
 	ResetAllAction(t->scope, NULL, NULL, &asdf);
 
 	if (anatrace) {
-		t->wave = XtVaCreateManagedWidget("anatrace", waveWidgetClass, t->paned,
-						  XtNwidth, width,
-					     XtNheight, height / splitby,
-						  NULL);
+		t->wave =
+		    XtVaCreateManagedWidget("anatrace", waveWidgetClass,
+					    t->paned, XtNwidth, width,
+					    XtNheight, height / splitby,
+					    NULL);
 	} else {
 		t->wave = NULL;
 	}
@@ -603,9 +620,12 @@ static void tracer_update_histograms(TRACER * t, spike_t * spikelist,
 				n++;
 				update_psth = 1;
 				ms_time = SPIKE_MSEC(spikelist, i);
-				athisto_add(t->psth, ms_time, psth_nbins, psth_bwidth);
+				athisto_add(t->psth, ms_time, psth_nbins,
+					    psth_bwidth);
 				if (last_time >= 0.0) {
-					if (athisto_add(t->isih, ms_time - last_time, isih_nbins, isih_bwidth))
+					if (athisto_add
+					    (t->isih, ms_time - last_time,
+					     isih_nbins, isih_bwidth))
 						update_isih = 1;
 				}
 				last_time = ms_time;
@@ -640,13 +660,9 @@ static int calc_sigmas(int nsamps, xword * data, float n, int *meanoffset)
 	return ((int) (0.5 + n * sqrt((double) sig)));
 }
 
-void tracer_update( TRACER * t,
-			  spike_t * spikelist,
-			  xword * anabuf,
-			  int nsamps,
-			  int c1,	/* from adtick */
-			  int c2,	/* to adtick */
-			  int decay_flag)
+void tracer_update(TRACER * t, spike_t * spikelist, xword * anabuf, int nsamps, int c1,	/* from adtick */
+		   int c2,	/* to adtick */
+		   int decay_flag)
 {
 	int pre, post;
 	int fc;
@@ -656,7 +672,7 @@ void tracer_update( TRACER * t,
 
 	if (anabuf == NULL) {
 		spiker_getAnalogBuffers(&nsamps, &anabufs);
-		anabuf = anabufs[GI("detect.tracer_channel")-1];
+		anabuf = anabufs[GI("detect.tracer_channel") - 1];
 		free(anabufs);
 	}
 
@@ -666,14 +682,17 @@ void tracer_update( TRACER * t,
 		 * until a safe time to kill the windows off..
 		 */
 		if (t->next)
-			tracer_update(t->next, spikelist, anabuf, nsamps, c1, c2, decay_flag);
+			tracer_update(t->next, spikelist, anabuf, nsamps,
+				      c1, c2, decay_flag);
 		DestroyTracer(t);
 	} else {
 		if (toggle_get(t->active)) {
 			if (t->wave != NULL) {
 				int mean, sigma;
 
-				sigma = calc_sigmas(nsamps, anabuf, (float) 3.0, &mean);
+				sigma =
+				    calc_sigmas(nsamps, anabuf,
+						(float) 3.0, &mean);
 				sigma -= mean;
 				mean = 0;
 
@@ -684,40 +703,65 @@ void tracer_update( TRACER * t,
 #endif				/* __tdtproc__ */
 				if (c1 != c2)
 					XtVaSetValues(t->wave,
-					  XtNcursor1, c1, XtNcursor2, c2,
-						      XtNhorizCursor1, sigma, XtNhorizCursor2, -sigma,
-						      XtNshowHorizCursor1, True, XtNshowHorizCursor2, True,
-						      XtNfc, fc, NULL);
+						      XtNcursor1, c1,
+						      XtNcursor2, c2,
+						      XtNhorizCursor1,
+						      sigma,
+						      XtNhorizCursor2,
+						      -sigma,
+						      XtNshowHorizCursor1,
+						      True,
+						      XtNshowHorizCursor2,
+						      True, XtNfc, fc,
+						      NULL);
 				else
 					XtVaSetValues(t->wave,
-						      XtNhorizCursor1, sigma, XtNhorizCursor2, -sigma,
-						      XtNshowHorizCursor1, True, XtNshowHorizCursor2, True,
-						      XtNfc, fc, NULL);
+						      XtNhorizCursor1,
+						      sigma,
+						      XtNhorizCursor2,
+						      -sigma,
+						      XtNshowHorizCursor1,
+						      True,
+						      XtNshowHorizCursor2,
+						      True, XtNfc, fc,
+						      NULL);
 
 				XtWaveSetWaveformOffset(t->wave,
-				 anabuf, nsamps, 2, -RANGE, RANGE, mean);
+							anabuf, nsamps, 2,
+							-RANGE, RANGE,
+							mean);
 			}
 			if (t->psth && t->isih)
-				tracer_update_histograms(t, spikelist, decay_flag);
+				tracer_update_histograms(t, spikelist,
+							 decay_flag);
 
-			pre = RND2INT(GF("mspre") * (float) is_adFc / 1000.0);
-			post = RND2INT(GF("mspost") * (float) is_adFc / 1000.0);
+			pre =
+			    RND2INT(GF("mspre") * (float) is_adFc /
+				    1000.0);
+			post =
+			    RND2INT(GF("mspost") * (float) is_adFc /
+				    1000.0);
 
 			if (pre < 0)
 				pre = 1 * is_adFc / 1000;
 			if (post < 0)
 				post = 2 * is_adFc / 1000;
 
-			max = (int) (1000.0 * (float) nsamps / (float) is_adFc);
+			max =
+			    (int) (1000.0 * (float) nsamps /
+				   (float) is_adFc);
 /** WARNING: this assumes that adFc is the same as evtFc..  */
 
 			/* mask = (!strcmp(GS("detect.mode"),"ss")) ? t->mask : MU_CODE; */
-			dynraster_add(t->raster, max, spikelist, t->mask, 0, 0);
+			dynraster_add(t->raster, max, spikelist, t->mask,
+				      0, 0);
 
-			plotUnitPerievent(t->scope, anabuf, 0, nsamps, pre, post,
-					  GI("maxTraces"), spikelist, t->mask, 1, GI("autoscale"));
+			plotUnitPerievent(t->scope, anabuf, 0, nsamps, pre,
+					  post, GI("maxTraces"), spikelist,
+					  t->mask, 1, GI("autoscale"));
 		}
 		if (t->next)
-			tracer_update(t->next, spikelist, anabuf, nsamps, c1, c2, decay_flag);
+			tracer_update(t->next, spikelist, anabuf, nsamps,
+				      c1, c2, decay_flag);
 	}
 }
