@@ -6,7 +6,7 @@
 */
 
 /******************************************************************
-**  RCSID: $Id: waver.h,v 2.44 1999/02/14 05:05:12 bjarthur Exp $
+**  RCSID: $Id: waver.h,v 2.45 2002/07/15 04:30:25 cmalek Exp $
 ** Program: dowl
 **  Module: waver.h
 **  Author: mazer
@@ -22,16 +22,16 @@
 *********************************************************************/
 
 struct WavefileViewData {
-  Widget nlabel, clabel;
-  Widget left, right;
-  int cpos;
-  char *filename;
+	Widget nlabel, clabel;
+	Widget left, right;
+	int cpos;
+	char *filename;
 };
 
-extern Widget 	canvaswaver_new(Widget, Dimension, Dimension);
-extern void	plotUnitPerievent(Widget, xword*, int, int, int, int, int, int*,
-                      int, int, int);
-extern Widget 	popfilewaver_new(Widget, char*, int, Dimension, Dimension,
-                      Widget*, Widget*, char**);
-extern Widget 	popfilewaver2_new(Widget, char*, Dimension, Dimension);
-extern Widget 	waveview_new(Widget, Widget*, Widget*, int, int);
+extern Widget canvaswaver_new(Widget, Dimension, Dimension);
+extern void plotUnitPerievent(Widget, xword *, int, int, int, int, int,
+			      int *, int, int, int);
+extern Widget popfilewaver_new(Widget, char *, int, Dimension, Dimension,
+			       Widget *, Widget *, char **);
+extern Widget popfilewaver2_new(Widget, char *, Dimension, Dimension);
+extern Widget waveview_new(Widget, Widget *, Widget *, int, int);
