@@ -6,7 +6,7 @@
  */
 
 /******************************************************************
-**  RCSID: $Id: xcalibur.c,v 1.24 2001/04/12 04:33:28 cmalek Exp $
+**  RCSID: $Id: xcalibur.c,v 1.25 2002/07/15 04:30:26 cmalek Exp $
 ** Program: calib
 **  Module: 
 **  Author: bjarthur
@@ -55,7 +55,7 @@ static void ModuleStartFn(Widget, RunData *, int);
 static void ModuleStartCB(Widget, XtPointer, XtPointer);
 static void HelpCB(Widget, XtPointer, XtPointer);
 static void ModuleTempCB(Widget, XtPointer, XtPointer);
-static void ModuleCloseCB(Widget, XtPointer, XtPointer );
+static void ModuleCloseCB(Widget, XtPointer, XtPointer);
 static void ModuleNamedTempCB(Widget, XtPointer, XtPointer);
 static void make_close_help(Widget, char *, DockSlot *);
 static void QuitAction(Widget, XEvent *, String *, Cardinal *);
@@ -72,7 +72,8 @@ static void usage(char *pname, char *badarg)
 	fprintf(stderr, "xcalibur -- Version %s \n", XDPHYS_VERSION);
 
 	if (badarg)
-		fprintf(stderr, "\n%s: unknown argument \"%s\"\n\n", pname, badarg);
+		fprintf(stderr, "\n%s: unknown argument \"%s\"\n\n", pname,
+			badarg);
 
 	if (badarg)
 		exit(1);
@@ -95,8 +96,7 @@ static float lpt_freq[MAX_PT_PTS], rpt_freq[MAX_PT_PTS];
 static float lpt_mag[MAX_PT_PTS], rpt_mag[MAX_PT_PTS];
 static float lpt_phi[MAX_PT_PTS], rpt_phi[MAX_PT_PTS];
 
-static Field ws_prefs[] =
-{
+static Field ws_prefs[] = {
 	{WS_VSEP, "Stimulus Preferences"},
 	{"Reps", "%d", 4, "3"},
 	{"Dur (ms)", "%d", 4, "100"},
@@ -131,13 +131,12 @@ static Field ws_prefs[] =
 	{WS_VSEP, "Testing Flags"},
 	{"use_atten", "%b", 1, "1"},
 	{"use_eq", "%b", 1, "1"},
-#endif	/* __test__ */
-#endif							/* __tdtproc__ */
+#endif				/* __test__ */
+#endif				/* __tdtproc__ */
 	{NULL},
 };
 
-static Field StandardParams[] =
-{
+static Field StandardParams[] = {
 	{"Reps (#)", "%d", 2},
 	{"Dur (ms)", "%d", 4},
 	{"Rise (ms)", "%d", 2},
@@ -157,9 +156,9 @@ static Field StandardParams[] =
 	{"version", "%s", 60},
 	{"time", "%s", 60},
 	{"timestamp", "%d", 12},
-  { "xcalibur.fname", "%s", 32 },
-  { "ana-save",          "%b", 1 },
-  { "ana-decimate (by)", "%d", 3 },
+	{"xcalibur.fname", "%s", 32},
+	{"ana-save", "%b", 1},
+	{"ana-decimate (by)", "%d", 3},
 };
 
 static void lock_worksheets(void)
@@ -191,9 +190,11 @@ void plottrace(xword * ibuf, int a, int b)
 
 	out = is_getDAbuffer(&nsamps);
 	XtWaveSetWaveform(lwv, ibuf + 2 * a, (b - a), 2, -RANGE, RANGE);
-	XtWaveSetWaveform(rwv, 1 + ibuf + 2 * a, (b - a), 2, -RANGE, RANGE);
+	XtWaveSetWaveform(rwv, 1 + ibuf + 2 * a, (b - a), 2, -RANGE,
+			  RANGE);
 	XtWaveSetWaveform(lwv_out, out + 2 * a, (b - a), 2, -RANGE, RANGE);
-	XtWaveSetWaveform(rwv_out, 1 + out + 2 * a, (b - a), 2, -RANGE, RANGE);
+	XtWaveSetWaveform(rwv_out, 1 + out + 2 * a, (b - a), 2, -RANGE,
+			  RANGE);
 }
 
 #endif
@@ -236,10 +237,12 @@ int load_mic_adjust_data(int use_default, float *SoL, float *SoR)
 		strcpy(fbuf, "$(XDPHYSDIR)/calib/$(HOST).kleft.fr");
 		filename = envexpand(fbuf);
 		if (!probefile(filename)) {
-			fprintf(stderr, "xcalibur: %s not found\n", filename);
+			fprintf(stderr, "xcalibur: %s not found\n",
+				filename);
 			strcpy(fbuf, "$(XDPHYSDIR)/calib/local.kleft.fr");
 			filename = envexpand(fbuf);
-			fprintf(stderr, "xcalibur: trying %s \n", filename);
+			fprintf(stderr, "xcalibur: trying %s \n",
+				filename);
 		}
 	}
 	if (strcmp(filename, "")) {
@@ -247,26 +250,32 @@ int load_mic_adjust_data(int use_default, float *SoL, float *SoR)
 			alert("Can't find Mic_Adjust_Left.");
 			return (0);
 		}
-		if ((fd = FD_read(filename,0)) == NULL) {
+		if ((fd = FD_read(filename, 0)) == NULL) {
 			alert("Can't read Mic_Adjust_Left: %s", filename);
 			lpt_n = 0;
 			ret_val = 0;
 		} else {
 			if (*FD_GV(fd, "Reference_Channel") == 'L') {
-				if (strcmp("", FD_GV(fd, "Mic_Adjust_Right"))) {
-					alert("%s has a non-blank non-ref-channel Mic_Adjust field.",
-						  filename);
+				if (strcmp
+				    ("", FD_GV(fd, "Mic_Adjust_Right"))) {
+					alert
+					    ("%s has a non-blank non-ref-channel Mic_Adjust field.",
+					     filename);
 					return (0);
 				}
 			} else if (*FD_GV(fd, "Reference_Channel") == 'R') {
-				if (strcmp("", FD_GV(fd, "Mic_Adjust_Left"))) {
-					alert("%s has a non-blank non-ref-channel Mic_Adjust field.",
-						  filename);
+				if (strcmp
+				    ("", FD_GV(fd, "Mic_Adjust_Left"))) {
+					alert
+					    ("%s has a non-blank non-ref-channel Mic_Adjust field.",
+					     filename);
 					return (0);
 				}
 			}
 			if (strcmp(fd->modname, "fr")) {
-				alert("Mic_Adjust_Left file is not a .fr file.", filename);
+				alert
+				    ("Mic_Adjust_Left file is not a .fr file.",
+				     filename);
 				lpt_n = 0;
 				ret_val = 0;
 			} else {
@@ -277,22 +286,40 @@ int load_mic_adjust_data(int use_default, float *SoL, float *SoR)
 				lphis = fr_get_lphis(fd);
 				rphis = fr_get_rphis(fd);
 
-				for (lpt_n = 0; (lpt_n < ndata) && (lpt_n < MAX_PT_PTS); lpt_n++) {
+				for (lpt_n = 0;
+				     (lpt_n < ndata)
+				     && (lpt_n < MAX_PT_PTS); lpt_n++) {
 					lpt_freq[lpt_n] = freqs[lpt_n];
-					if (*FD_GV(fd, "Reference_Channel") == 'L') {
-						lpt_mag[lpt_n] = rmags[lpt_n] / lmags[lpt_n];
-						lpt_phi[lpt_n] = rphis[lpt_n] - lphis[lpt_n];
-					} else if (*FD_GV(fd, "Reference_Channel") == 'R') {
-						lpt_mag[lpt_n] = lmags[lpt_n] / rmags[lpt_n];
-						lpt_phi[lpt_n] = lphis[lpt_n] - rphis[lpt_n];
+					if (*FD_GV(fd, "Reference_Channel")
+					    == 'L') {
+						lpt_mag[lpt_n] =
+						    rmags[lpt_n] /
+						    lmags[lpt_n];
+						lpt_phi[lpt_n] =
+						    rphis[lpt_n] -
+						    lphis[lpt_n];
+					} else
+					    if (*FD_GV
+						(fd,
+						 "Reference_Channel") ==
+						'R') {
+						lpt_mag[lpt_n] =
+						    lmags[lpt_n] /
+						    rmags[lpt_n];
+						lpt_phi[lpt_n] =
+						    lphis[lpt_n] -
+						    rphis[lpt_n];
 					}
 				}
 				if (*FD_GV(fd, "Reference_Channel") == 'L') {
 					if (SoL)
-						(*SoL) = FD_GF(fd, "So_Left");
-				} else if (*FD_GV(fd, "Reference_Channel") == 'R') {
+						(*SoL) =
+						    FD_GF(fd, "So_Left");
+				} else if (*FD_GV(fd, "Reference_Channel")
+					   == 'R') {
 					if (SoL)
-						(*SoL) = FD_GF(fd, "So_Right");
+						(*SoL) =
+						    FD_GF(fd, "So_Right");
 				}
 				unwrap(lpt_phi, lpt_n, M_PI);
 
@@ -301,11 +328,13 @@ int load_mic_adjust_data(int use_default, float *SoL, float *SoR)
 					ret_val = 0;
 				}
 				if (lpt_n < ndata) {
-					alert("Mic_Adjust_Left is too large to fit in alloc'd memory!");
+					alert
+					    ("Mic_Adjust_Left is too large to fit in alloc'd memory!");
 					ret_val = 0;
 				}
 				FD_free(fd);
-				fprintf(stderr, "xcalibur: using %s \n", filename);
+				fprintf(stderr, "xcalibur: using %s \n",
+					filename);
 			}
 		}
 	} else
@@ -316,10 +345,12 @@ int load_mic_adjust_data(int use_default, float *SoL, float *SoR)
 		strcpy(fbuf, "$(XDPHYSDIR)/calib/$(HOST).kright.fr");
 		filename = envexpand(fbuf);
 		if (!probefile(filename)) {
-			fprintf(stderr, "xcalibur: %s not found\n", filename);
+			fprintf(stderr, "xcalibur: %s not found\n",
+				filename);
 			strcpy(fbuf, "$(XDPHYSDIR)/calib/local.kright.fr");
 			filename = envexpand(fbuf);
-			fprintf(stderr, "xcalibur: trying %s \n", filename);
+			fprintf(stderr, "xcalibur: trying %s \n",
+				filename);
 		}
 	}
 	if (strcmp(filename, "")) {
@@ -327,26 +358,32 @@ int load_mic_adjust_data(int use_default, float *SoL, float *SoR)
 			alert("Can't find Mic_Adjust_Right.");
 			return (0);
 		}
-		if ((fd = FD_read(filename,0)) == NULL) {
+		if ((fd = FD_read(filename, 0)) == NULL) {
 			alert("Can't read Mic_Adjust_Right: %s", filename);
 			rpt_n = 0;
 			ret_val = 0;
 		} else {
 			if (*FD_GV(fd, "Reference_Channel") == 'L') {
-				if (strcmp("", FD_GV(fd, "Mic_Adjust_Right"))) {
-					alert("%s has a non-blank non-ref-channel Mic_Adjust field.",
-						  filename);
+				if (strcmp
+				    ("", FD_GV(fd, "Mic_Adjust_Right"))) {
+					alert
+					    ("%s has a non-blank non-ref-channel Mic_Adjust field.",
+					     filename);
 					return (0);
 				}
 			} else if (*FD_GV(fd, "Reference_Channel") == 'R') {
-				if (strcmp("", FD_GV(fd, "Mic_Adjust_Left"))) {
-					alert("%s has a non-blank non-ref-channel Mic_Adjust field.",
-						  filename);
+				if (strcmp
+				    ("", FD_GV(fd, "Mic_Adjust_Left"))) {
+					alert
+					    ("%s has a non-blank non-ref-channel Mic_Adjust field.",
+					     filename);
 					return (0);
 				}
 			}
 			if (strcmp(fd->modname, "fr")) {
-				alert("Mic_Adjust_Right file is not a .fr file.", filename);
+				alert
+				    ("Mic_Adjust_Right file is not a .fr file.",
+				     filename);
 				rpt_n = 0;
 				ret_val = 0;
 			} else {
@@ -357,22 +394,40 @@ int load_mic_adjust_data(int use_default, float *SoL, float *SoR)
 				lphis = fr_get_lphis(fd);
 				rphis = fr_get_rphis(fd);
 
-				for (rpt_n = 0; (rpt_n < ndata) && (rpt_n < MAX_PT_PTS); rpt_n++) {
+				for (rpt_n = 0;
+				     (rpt_n < ndata)
+				     && (rpt_n < MAX_PT_PTS); rpt_n++) {
 					rpt_freq[rpt_n] = freqs[rpt_n];
-					if (*FD_GV(fd, "Reference_Channel") == 'L') {
-						rpt_mag[rpt_n] = rmags[rpt_n] / lmags[rpt_n];
-						rpt_phi[rpt_n] = rphis[rpt_n] - lphis[rpt_n];
-					} else if (*FD_GV(fd, "Reference_Channel") == 'R') {
-						rpt_mag[rpt_n] = lmags[rpt_n] / rmags[rpt_n];
-						rpt_phi[rpt_n] = lphis[rpt_n] - rphis[rpt_n];
+					if (*FD_GV(fd, "Reference_Channel")
+					    == 'L') {
+						rpt_mag[rpt_n] =
+						    rmags[rpt_n] /
+						    lmags[rpt_n];
+						rpt_phi[rpt_n] =
+						    rphis[rpt_n] -
+						    lphis[rpt_n];
+					} else
+					    if (*FD_GV
+						(fd,
+						 "Reference_Channel") ==
+						'R') {
+						rpt_mag[rpt_n] =
+						    lmags[rpt_n] /
+						    rmags[rpt_n];
+						rpt_phi[rpt_n] =
+						    lphis[rpt_n] -
+						    rphis[rpt_n];
 					}
 				}
 				if (*FD_GV(fd, "Reference_Channel") == 'L') {
 					if (SoR)
-						(*SoR) = FD_GF(fd, "So_Left");
-				} else if (*FD_GV(fd, "Reference_Channel") == 'R') {
+						(*SoR) =
+						    FD_GF(fd, "So_Left");
+				} else if (*FD_GV(fd, "Reference_Channel")
+					   == 'R') {
 					if (SoR)
-						(*SoR) = FD_GF(fd, "So_Right");
+						(*SoR) =
+						    FD_GF(fd, "So_Right");
 				}
 				unwrap(rpt_phi, rpt_n, M_PI);
 
@@ -381,11 +436,13 @@ int load_mic_adjust_data(int use_default, float *SoL, float *SoR)
 					ret_val = 0;
 				}
 				if (rpt_n < ndata) {
-					alert("Mic_Adjust_Left is too large to fit in alloc'd memory!");
+					alert
+					    ("Mic_Adjust_Left is too large to fit in alloc'd memory!");
 					ret_val = 0;
 				}
 				FD_free(fd);
-				fprintf(stderr, "xcalibur: using %s \n", filename);
+				fprintf(stderr, "xcalibur: using %s \n",
+					filename);
 			}
 		}
 	} else
@@ -401,9 +458,13 @@ void query_mic_adjust(float f, char channel, float *mag, float *phi)
 	if (channel == 'L') {
 		if (lpt_n) {
 			if (mag)
-				(*mag) = lin_interpolate(f, lpt_n, lpt_freq, lpt_mag);
+				(*mag) =
+				    lin_interpolate(f, lpt_n, lpt_freq,
+						    lpt_mag);
 			if (phi)
-				(*phi) = lin_interpolate(f, lpt_n, lpt_freq, lpt_phi);
+				(*phi) =
+				    lin_interpolate(f, lpt_n, lpt_freq,
+						    lpt_phi);
 		} else {
 			if (mag)
 				(*mag) = 1.0;
@@ -413,9 +474,13 @@ void query_mic_adjust(float f, char channel, float *mag, float *phi)
 	} else {
 		if (rpt_n) {
 			if (mag)
-				(*mag) = lin_interpolate(f, rpt_n, rpt_freq, rpt_mag);
+				(*mag) =
+				    lin_interpolate(f, rpt_n, rpt_freq,
+						    rpt_mag);
 			if (phi)
-				(*phi) = lin_interpolate(f, rpt_n, rpt_freq, rpt_phi);
+				(*phi) =
+				    lin_interpolate(f, rpt_n, rpt_freq,
+						    rpt_phi);
 		} else {
 			if (mag)
 				(*mag) = 1.0;
@@ -467,7 +532,8 @@ static void savestate(int bell)
 }
 
 
-static void SaveStateCB(Widget w, XtPointer client_data, XtPointer call_data)
+static void SaveStateCB(Widget w, XtPointer client_data,
+			XtPointer call_data)
 {
 	savestate(1);
 }
@@ -493,9 +559,9 @@ static void Quit(Widget w, XtPointer client_data, XtPointer call_data)
 
 int default_display_fn(char *datafile)
 {
-  if (getenv("XDPHYS_NO_GRAPH")==NULL)
-    FDObj_File_New(datafile, NULL, NULL);
-  return(1);
+	if (getenv("XDPHYS_NO_GRAPH") == NULL)
+		FDObj_File_New(datafile, NULL, NULL);
+	return (1);
 }
 
 static int appRun(int temp_run, RunData * info, Widget headline)
@@ -510,8 +576,8 @@ static int appRun(int temp_run, RunData * info, Widget headline)
 	FILEDATA *fd;
 #ifdef __tdtproc__
 	int epoch = GI("epoch");
-#endif							/* __tdtproc__ */
-  int ana_save;
+#endif				/* __tdtproc__ */
+	int ana_save;
 
 	if (temp_run == TEMP_YES) {
 		datafile = (char *) malloc(strlen(info->suffix) + 6);
@@ -522,7 +588,7 @@ static int appRun(int temp_run, RunData * info, Widget headline)
 		datafile = fileBox(buf, "w", "Save to ...");
 		if (datafile == NULL)
 			return (0);
-	} else {					/* TEMP_NO */
+	} else {		/* TEMP_NO */
 		char buf[100];
 		sprintf(buf, ".%s", info->suffix);
 		datafile = fileBox(buf, "w", "Save to ...");
@@ -530,7 +596,7 @@ static int appRun(int temp_run, RunData * info, Widget headline)
 			return (0);
 	}
 
-  SS("xcalibur.fname",datafile);
+	SS("xcalibur.fname", datafile);
 
 	if (GI("Comments")) {
 		if ((temp_run == TEMP_NO) || (temp_run == TEMP_NAMED)) {
@@ -543,7 +609,7 @@ static int appRun(int temp_run, RunData * info, Widget headline)
 		}
 	}
 	if (probefile(datafile) && (temp_run == TEMP_NO)) {
-		if ((fd = FD_read(datafile,0)) == NULL) {
+		if ((fd = FD_read(datafile, 0)) == NULL) {
 			alert("FD_read failed.");
 			return (0);
 		}
@@ -575,15 +641,16 @@ static int appRun(int temp_run, RunData * info, Widget headline)
 	is_init(GF("daFc"), 0.0, 0.0, epoch, epoch);
 	ws_tows(NULL, NULL);
 	is_shutdown();
-#endif /* __tdtproc__ */
+#endif				/* __tdtproc__ */
 
 	fprintf(datafp, ";; xcalibur %s ver %s\n",
-			info->suffix, XDPHYS_VERSION);
+		info->suffix, XDPHYS_VERSION);
 
 	/* Comment Block */
 	fprintf(datafp, "COMMENTS\n");
 	if (debugflag)
-		fprintf(stderr, "comments=<%s>\n", comments ? comments : "NULL");
+		fprintf(stderr, "comments=<%s>\n",
+			comments ? comments : "NULL");
 	if (GI("Comments"))
 		writeComments(comments, datafp);
 	fprintf(datafp, "END_COMMENTS\n");
@@ -595,7 +662,7 @@ static int appRun(int temp_run, RunData * info, Widget headline)
 		fprintf(datafp, "depvar=%s\n", info->depvar);
 	fprintf(datafp, "; StandardParams\n");
 	ws_write(datafp, StandardParams, WS_N(StandardParams), NULL);
-	/*fprintf(datafp, "xcalibur.fname=%s\n", datafile);*/
+	/*fprintf(datafp, "xcalibur.fname=%s\n", datafile); */
 	fprintf(datafp, "END_PARAMS\n");
 
 	/* Rasterdata Block.. may or may not end properly */
@@ -608,14 +675,15 @@ static int appRun(int temp_run, RunData * info, Widget headline)
 	if (datafp) {
 		fprintf(datafp, "END_RASTERDATA\n");
 		if (scan_result <= 0)
-			fprintf(datafp, ";; NOTE: run aborted or failed!!\n");
+			fprintf(datafp,
+				";; NOTE: run aborted or failed!!\n");
 		fclose(datafp);
 /*
 		if (analogfp)
 			fclose(analogfp);
 */
 	}
-	ws_tosvars(NULL, NULL);		/* in case of any changes during run.. */
+	ws_tosvars(NULL, NULL);	/* in case of any changes during run.. */
 
 	if (scan_result > 0) {
 		/* Successful run completed, save the file */
@@ -625,7 +693,7 @@ static int appRun(int temp_run, RunData * info, Widget headline)
 		/* Run was aborted, if temp_run, then delete the file;
 		 * otherwise, give the user some options..  */
 		i = pop_box("Aborted, what do to with partial data file?",
-					"Delete", "Save", "Save and Plot");
+			    "Delete", "Save", "Save and Plot");
 		switch (i) {
 		case 1:
 #if 0
@@ -661,7 +729,9 @@ static int appRun(int temp_run, RunData * info, Widget headline)
 			/* note that compress/gzip will fail if compressed version is bigger
 			 * than the original -- so don't be surprised if not all the
 			 * ana files get compressed..  */
-			fprintf(stderr, "Warning: compressing \"%s\" in background", anafile);
+			fprintf(stderr,
+				"Warning: compressing \"%s\" in background",
+				anafile);
 			sprintf(buf, "exec gzip %s", anafile);
 			system_noblock(buf);
 		}
@@ -705,7 +775,7 @@ static void ModuleStartFn(Widget w, RunData * info, int temp_run)
 }
 
 static void ModuleStartCB(Widget w, XtPointer info_blah,
-						  XtPointer call_data)
+			  XtPointer call_data)
 {
 	RunData *info = (RunData *) info_blah;
 
@@ -713,7 +783,7 @@ static void ModuleStartCB(Widget w, XtPointer info_blah,
 }
 
 static void ModuleCloseCB(Widget w, XtPointer slot_blah,
-						  XtPointer call_data)
+			  XtPointer call_data)
 {
 	DockSlot *slot = (DockSlot *) slot_blah;
 
@@ -722,7 +792,7 @@ static void ModuleCloseCB(Widget w, XtPointer slot_blah,
 }
 
 static void ModuleTempCB(Widget w, XtPointer info_blah,
-						 XtPointer call_data)
+			 XtPointer call_data)
 {
 	RunData *info = (RunData *) info_blah;
 
@@ -730,24 +800,22 @@ static void ModuleTempCB(Widget w, XtPointer info_blah,
 }
 
 static void ModuleNamedTempCB(Widget w, XtPointer info_blah,
-							  XtPointer call_data)
+			      XtPointer call_data)
 {
 	RunData *info = (RunData *) info_blah;
 
 	ModuleStartFn(w, info, TEMP_NAMED);
 }
 
-void *make_module_info(
-						  char *depvar,		/* name of dependent variable (eg "itd") */
-						  char *suffix,		/* suffix for file-type i.d. */
-						  char *helpfile,	/* search string for help file */
-						  int (*pre) (),	/* call before scan (i.e. to LOCK ws) */
-						  int (*scan) (),	/* actually collect the data.. */
-						  int (*post) (),	/* call after scan (i.e. to UNLOCK ws) */
-						  int (*display) (),
-						  FieldList params,		/* parameters for writing headers */
-						  int nparams)
-{								/* number of parameters */
+void *make_module_info(char *depvar,	/* name of dependent variable (eg "itd") */
+		       char *suffix,	/* suffix for file-type i.d. */
+		       char *helpfile,	/* search string for help file */
+		       int (*pre) (),	/* call before scan (i.e. to LOCK ws) */
+		       int (*scan) (),	/* actually collect the data.. */
+		       int (*post) (),	/* call after scan (i.e. to UNLOCK ws) */
+		       int (*display) (), FieldList params,	/* parameters for writing headers */
+		       int nparams)
+{				/* number of parameters */
 	RunData *info;
 
 	info = (RunData *) malloc(sizeof(RunData));
@@ -768,58 +836,55 @@ static void make_close_help(Widget handle, char *name, DockSlot * slot)
 	Widget w1, w2;
 
 	w1 = button_new(XtParent(handle), "Close", "Close", ModuleCloseCB,
-					slot, handle, NULL);
+			slot, handle, NULL);
 	accel_from(XtParent(handle), w1);
 
 	w2 = button_new(XtParent(handle), "Help", "Help", HelpCB,
-					name, w1, NULL);
+			name, w1, NULL);
 	accel_from(XtParent(handle), w2);
 }
 
 void make_start_temp(Widget handle, RunData * info, XtCallbackProc StartCB,
-					 XtCallbackProc TempCB, DockSlot * slot)
+		     XtCallbackProc TempCB, DockSlot * slot)
 {
 	Widget w1, w2, w3, w4, w5;
 
 	w1 = button_new(XtParent(handle), "Close", "Close", ModuleCloseCB,
-					slot, handle, NULL);
+			slot, handle, NULL);
 	accel_from(XtParent(handle), w1);
 
 	w2 = button_new(XtParent(handle), "Help", "Help", HelpCB,
-					info->helpfile, w1, NULL);
+			info->helpfile, w1, NULL);
 	accel_from(XtParent(handle), w2);
 
 	w3 = button_new(XtParent(handle), "Start", "Start",
-					StartCB ? StartCB : ModuleStartCB,
-					info, w2, NULL);
+			StartCB ? StartCB : ModuleStartCB, info, w2, NULL);
 	accel_from(XtParent(handle), w3);
 
 	w4 = button_new(XtParent(handle), "Temp", "Temp",
-					TempCB ? TempCB : ModuleTempCB,
-					info, w3, NULL);
+			TempCB ? TempCB : ModuleTempCB, info, w3, NULL);
 	accel_from(XtParent(handle), w4);
 
 	w5 = button_new(XtParent(handle), "Named-Temp", "Named-Temp",
-					ModuleNamedTempCB, info, w4, NULL);
+			ModuleNamedTempCB, info, w4, NULL);
 	accel_from(XtParent(handle), w5);
 }
 
 static void QuitAction(Widget w, XEvent * event, String * params,
-					   Cardinal * num_params)
+		       Cardinal * num_params)
 {
 	Quit(NULL, NULL, NULL);
 }
 
 static void install_actions(void)
 {
-	static XtActionsRec actionTable[] =
-	{
+	static XtActionsRec actionTable[] = {
 		{"quit", QuitAction},
 		{"pause", PauseAction},
 	};
 
 	XtAppAddActions(XtWidgetToApplicationContext(TopLevel),
-					actionTable, XtNumber(actionTable));
+			actionTable, XtNumber(actionTable));
 }
 
 static int calibmain(int ac, char **av, char *appname, char *classname)
@@ -829,8 +894,7 @@ static int calibmain(int ac, char **av, char *appname, char *classname)
 	Widget h;
 	char tmp[64];
 
-	static MENU_ENTRY OtherMenu[] =
-	{
+	static MENU_ENTRY OtherMenu[] = {
 		{"Other Menu", NULL},
 		{"Combine fr files", CombineFrFiles, (void *) NULL},
 		{NULL}
@@ -843,14 +907,15 @@ static int calibmain(int ac, char **av, char *appname, char *classname)
 	initsvars();
 
 	if (!loadvars(statefile, global_svar_table))
-		fprintf(stderr, "warning: can't find config file \"%s\"\n", statefile);
+		fprintf(stderr, "warning: can't find config file \"%s\"\n",
+			statefile);
 
 	SS("caltype", "? None ?");
 
 	install_xcalibur_plotMethods();
 
 	startx(&ac, av, appname ? appname : "xcalibur",
-		   classname ? classname : "xcalibur");
+	       classname ? classname : "xcalibur");
 	install_actions();
 
 #define isarg(pat) (strncmp(av[arg], pat, strlen(av[arg])) == 0)
@@ -871,8 +936,10 @@ static int calibmain(int ac, char **av, char *appname, char *classname)
 	mainform = form_new(TopLevel, "main", 0);
 
 	w = NULL;
-	w = button_new(mainform, "About", "About", AboutCB, (void *) NULL, w, headline);
-	w = button_new(mainform, "Help", "Help", HelpCB, (void *) NULL, w, headline);
+	w = button_new(mainform, "About", "About", AboutCB, (void *) NULL,
+		       w, headline);
+	w = button_new(mainform, "Help", "Help", HelpCB, (void *) NULL, w,
+		       headline);
 	w = button_new(mainform, "Quit", "Quit", Quit, NULL, w, headline);
 	w = menu_new(mainform, "Other", OtherMenu, w, headline);
 
@@ -885,12 +952,14 @@ static int calibmain(int ac, char **av, char *appname, char *classname)
 	XtVaSetValues(waveshell_out, XtNfromVert, waveshell, NULL);
 
 	tooldock = dock_new(mainform, NULL, 20, &dockform);
-	XtVaSetValues(dockform, XtNfromVert, w, XtNfromHoriz, waveshell, NULL);
+	XtVaSetValues(dockform, XtNfromVert, w, XtNfromHoriz, waveshell,
+		      NULL);
 
 	install_modules(tooldock);
 
 	i = dock_add(tooldock, "Prefs",
-				 pop_ws_new(TopLevel, ws_prefs, "Prefs", &h, NULL, NULL));
+		     pop_ws_new(TopLevel, ws_prefs, "Prefs", &h, NULL,
+				NULL));
 	make_close_help(h, "prefs", &tooldock->slots[i]);
 
 	sprintf(tmp, "Version %s", XDPHYS_VERSION);
@@ -909,7 +978,7 @@ static int calibmain(int ac, char **av, char *appname, char *classname)
 	DisplayNotice(CopyrightMessage());
 #endif
 
-	return (1);					/* caller should enter xloop */
+	return (1);		/* caller should enter xloop */
 }
 
 int main(int ac, char **av)
